@@ -46,7 +46,8 @@
 #include <headers.h>    /* header definitions and handler */
 
 /* OS check for printing %llu and %lli*/
-#ifdef __unix__
+//#ifdef __unix__
+#if defined (__unix__) || (defined (__APPLE__) && defined (__MACH__))
 
 #elif defined(_WIN32) || defined(WIN32) || defined(_WIN64) || defined(WIN64) 
   #define OS_Windows
